@@ -126,7 +126,7 @@ bool RarArch::processLine( const TQCString &line )
   }
 
   TQStringList entry;
-  TQStringList parsedData = TQStringList::split(QChar(' '), uline);
+  TQStringList parsedData = TQStringList::split(TQChar(' '), uline);
 
   if (m_version < VERSION_5) {
     if (m_isFirstLine)
