@@ -374,7 +374,7 @@ void KgpgKeyInfo::slotSetPhoto(const TQPixmap &pix)
 //	kdDebug(2100) << k_funcinfo << endl;
 	TQImage dup=pix.convertToImage();
 	TQPixmap dup2;
-	dup2.convertFromImage(dup.scale(prop->pLPhoto->width(),prop->pLPhoto->height(),TQ_ScaleMin));
+	dup2.convertFromImage(dup.scale(prop->pLPhoto->width(),prop->pLPhoto->height(),TQImage::ScaleMin));
 	prop->pLPhoto->setPixmap(dup2);
 }
 
