@@ -365,7 +365,7 @@ CFindNavigatorDialog::CFindNavigatorDialog( TQWidget *parent, const char *name,
 
   mKey = new TQLineEdit( plainPage() );
   mKey->setMinimumWidth( fontMetrics().width("M") * 20 );
-  mKey->setFocusPolicy( TQ_NoFocus );
+  mKey->setFocusPolicy( TQWidget::NoFocus );
   hbox->addWidget( mKey );
 
   topLayout->addSpacing( spacingHint() ); // A little bit extra space
