@@ -133,7 +133,7 @@ KHexEdit::KHexEdit( KDataBuffer *Buffer, TQWidget *Parent, const char *Name, WFl
 
   // get the full control
   viewport()->setFocusProxy( this );
-  viewport()->setFocusPolicy( TQ_WheelFocus );
+  viewport()->setFocusPolicy( TQWidget::WheelFocus );
 
   viewport()->installEventFilter( this );
   installEventFilter( this );
@@ -1178,7 +1178,7 @@ void KHexEdit::showEvent( TQShowEvent *e )
 
 bool KHexEdit::eventFilter( TQObject *O, TQEvent *E )
 {
-  if( TQT_BASE_OBJECT(O) == TQT_BASE_OBJECT(this) || TQT_BASE_OBJECT(O) == TQT_BASE_OBJECT(viewport()) )
+  if( O == this || O == viewport() )
   {
     if( E->type() == TQEvent::FocusIn )
     {
