@@ -141,7 +141,7 @@ bool FilesystemWidget::eventFilter(TQObject *o, TQEvent *e)
   while ((filesystem = it.current()) != 0) {
     ++it;
 
-    if (TQT_BASE_OBJECT(filesystem->display()) == TQT_BASE_OBJECT(o)) {
+    if (filesystem->display() == o) {
       progressBar = filesystem->display();
       break;
     }
@@ -149,7 +149,7 @@ bool FilesystemWidget::eventFilter(TQObject *o, TQEvent *e)
     ++i;
   }
 
-  if (TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(progressBar) && e->type() == TQEvent::MouseButtonPress)
+  if (o == progressBar && e->type() == TQEvent::MouseButtonPress)
   {
     switch(TQT_TQMOUSEEVENT(e)->button()) {
       case Qt::RightButton:
