@@ -314,7 +314,7 @@ karamba::karamba(TQString fn, TQString name, bool reloading, int instance,
   this->setMouseTracking(true);
 
 
-  setFocusPolicy(TQ_StrongFocus);
+  setFocusPolicy(TQWidget::StrongFocus);
 }
 
 karamba::~karamba()
